==================
Installation Guide
==================

Melexis Warnings plugin is available as a package on `PyPI
<https://pypi.org/project/mlx.warnings/>`_. Once installed, it
offers direct command line invocation (no need to run python infront).
Installation is as simple as:

.. code-block:: bash

    # released version from PyPI
    pip3 install mlx.warnings

    # editable package based on master branch
    git clone https://github.com/melexis/warnings-plugin.git
    pip3 install -e warnings-plugin

So far we are not aware of any problems with installation of the plugin, but in
case you have any please open an Issue.
